@@ -7,6 +7,18 @@ def sql(key):
     :return:
     """
     switcher = {
+        'OpensearchSLO': {
+            'sql': "SELECT `id` FROM kai_service where name LIKE '%opensearch服务SLO%' order  by create_time desc;",
+            'database': 'AnyRobot'
+        },
+        'HostServiceSLO': {
+            'sql': "SELECT `id` FROM kai_service where name LIKE '%AR主机服务SLO%' order  by create_time desc;",
+            'database': 'AnyRobot'
+        },
+        'ServiceSLO': {
+            'sql': "SELECT `id` FROM kai_service where name LIKE '%AR服务SLO%' order  by create_time desc;",
+            'database': 'AnyRobot'
+        },
         'MySystemMetric':{
             'sql':"SELECT `groupId` FROM loggroup where groupName LIKE '%mysystemmetric%' order  by createTime desc;",
             'database': 'AnyRobot'
